package com.sun.java.swing.plaf.motif;

import javax.swing.plaf.ActionMapUIResource;
import javax.swing.UIManager;
import javax.swing.ActionMap;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.SwingUtilities;
import java.awt.Toolkit;
import java.awt.Dimension;
import javax.swing.LookAndFeel;
import javax.swing.border.Border;
import javax.swing.plaf.UIResource;
import javax.swing.JInternalFrame;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.KeyStroke;
import java.awt.Color;
import javax.swing.plaf.basic.BasicInternalFrameUI;

public class MotifInternalFrameUI extends BasicInternalFrameUI
{
    Color color;
    Color highlight;
    Color shadow;
    MotifInternalFrameTitlePane titlePane;
    @Deprecated
    protected KeyStroke closeMenuKey;
    
    public static ComponentUI createUI(JComponent component) {
        return new MotifInternalFrameUI((JInternalFrame)component);
    }
    
    public MotifInternalFrameUI(JInternalFrame b) {
        super(b);
    }
    
    @Override
    public void installUI(JComponent c) {
        super.installUI(c);
        this.setColors((JInternalFrame)c);
    }
    
    @Override
    protected void installDefaults() {
        Border border = this.frame.getBorder();
        this.frame.setLayout(this.internalFrameLayout = this.createLayoutManager());
        if (border == null || border instanceof UIResource) {
            this.frame.setBorder(new MotifBorders.InternalFrameBorder(this.frame));
        }
    }
    
    @Override
    protected void installKeyboardActions() {
        super.installKeyboardActions();
        this.closeMenuKey = KeyStroke.getKeyStroke(27, 0);
    }
    
    @Override
    protected void uninstallDefaults() {
        LookAndFeel.uninstallBorder(this.frame);
        this.frame.setLayout(null);
        this.internalFrameLayout = null;
    }
    
    private JInternalFrame getFrame() {
        return this.frame;
    }
    
    public JComponent createNorthPane(JInternalFrame internalFrame) {
        return this.titlePane = new MotifInternalFrameTitlePane(internalFrame);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        return Toolkit.getDefaultToolkit().getScreenSize();
    }
    
    @Override
    protected void uninstallKeyboardActions() {
        super.uninstallKeyboardActions();
        if (this.isKeyBindingRegistered()) {
            JInternalFrame.JDesktopIcon desktopIcon = this.frame.getDesktopIcon();
            SwingUtilities.replaceUIActionMap(desktopIcon, null);
            SwingUtilities.replaceUIInputMap(desktopIcon, 2, null);
        }
    }
    
    @Override
    protected void setupMenuOpenKey() {
        super.setupMenuOpenKey();
        ActionMap uiActionMap = SwingUtilities.getUIActionMap(this.frame);
        if (uiActionMap != null) {
            uiActionMap.put("showSystemMenu", new AbstractAction() {
                @Override
                public void actionPerformed(ActionEvent actionEvent) {
                    MotifInternalFrameUI.this.titlePane.showSystemMenu();
                }
                
                @Override
                public boolean isEnabled() {
                    return MotifInternalFrameUI.this.isKeyBindingActive();
                }
            });
        }
    }
    
    @Override
    protected void setupMenuCloseKey() {
        ActionMap uiActionMap = SwingUtilities.getUIActionMap(this.frame);
        if (uiActionMap != null) {
            uiActionMap.put("hideSystemMenu", new AbstractAction() {
                @Override
                public void actionPerformed(ActionEvent actionEvent) {
                    MotifInternalFrameUI.this.titlePane.hideSystemMenu();
                }
                
                @Override
                public boolean isEnabled() {
                    return MotifInternalFrameUI.this.isKeyBindingActive();
                }
            });
        }
        JInternalFrame.JDesktopIcon desktopIcon = this.frame.getDesktopIcon();
        if (SwingUtilities.getUIInputMap(desktopIcon, 2) == null) {
            Object[] keys = (Object[])(Object[])UIManager.get("DesktopIcon.windowBindings");
            if (keys != null) {
                SwingUtilities.replaceUIInputMap(desktopIcon, 2, LookAndFeel.makeComponentInputMap(desktopIcon, keys));
            }
        }
        if (SwingUtilities.getUIActionMap(desktopIcon) == null) {
            ActionMapUIResource uiActionMap2 = new ActionMapUIResource();
            uiActionMap2.put("hideSystemMenu", new AbstractAction() {
                @Override
                public void actionPerformed(ActionEvent actionEvent) {
                    ((MotifDesktopIconUI)MotifInternalFrameUI.access$000(MotifInternalFrameUI.this).getDesktopIcon().getUI()).hideSystemMenu();
                }
                
                @Override
                public boolean isEnabled() {
                    return MotifInternalFrameUI.this.isKeyBindingActive();
                }
            });
            SwingUtilities.replaceUIActionMap(desktopIcon, uiActionMap2);
        }
    }
    
    @Override
    protected void activateFrame(JInternalFrame internalFrame) {
        super.activateFrame(internalFrame);
        this.setColors(internalFrame);
    }
    
    @Override
    protected void deactivateFrame(JInternalFrame internalFrame) {
        this.setColors(internalFrame);
        super.deactivateFrame(internalFrame);
    }
    
    void setColors(JInternalFrame internalFrame) {
        if (internalFrame.isSelected()) {
            this.color = UIManager.getColor("InternalFrame.activeTitleBackground");
        }
        else {
            this.color = UIManager.getColor("InternalFrame.inactiveTitleBackground");
        }
        this.highlight = this.color.brighter();
        this.shadow = this.color.darker().darker();
        this.titlePane.setColors(this.color, this.highlight, this.shadow);
    }
    
    static JInternalFrame access$000(MotifInternalFrameUI motifInternalFrameUI) {
        return motifInternalFrameUI.getFrame();
    }
}
